==> 1.0.48.tar.gz: lib/modules/cart/cart_repo.dart <==
import 'package:graphql_flutter/graphql_flutter.dart';

import '../../GraphQLConfiguration.dart';
import 'cart_model.dart';

class CartRepo {
  var graphQLConfiguration;

  var serverCartCount;
  var cart = [];
  var removeCartDetail;
  var updatedCart, addedCart;
  CartRepo() {
    graphQLConfiguration = GraphQLConfiguration();
  }

  Future getServerCartCount(String userId) async {
    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var cartCountGql = """ 
              query serverCartCount(\$userId: String) {
              serverCartCount(userId: \$userId)
            }
            """;

    final vble = {
      "userId": userId,
    };
    QueryResult result = await _client.query(QueryOptions(
      document: gql(cartCountGql),
      variables: vble,
      fetchPolicy: FetchPolicy.networkOnly,
    ));

    if (!result.hasException) {
      var serverCartCountModel = result.data!["serverCartCount"];

      if (serverCartCountModel != null) {
        serverCartCount = cartCountFromJson(serverCartCountModel);
        return serverCartCount;
      }
    }
    return serverCartCount;
  }

  Future getCart(String userId) async {
    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var cartGql = """ 
             query getCart(\$userId: String) {
                  getCart(userId: \$userId) {
                    _id
                    packName
                    packId
                    packImage
                    packSku
                    setId
                    quantity
                    piece
                    setPrice
                    price
                    variant
                    igst
                    cgst
                    sgst
                    variantValue
                    isOutofstock
                    maximumQuantity
                    __typename
                  }
                }
            """;

    final vble = {
      "userId": userId,
    };
    QueryResult result = await _client.query(QueryOptions(
      document: gql(cartGql),
      variables: vble,
      fetchPolicy: FetchPolicy.networkOnly,
    ));

    if (!result.hasException) {
      var serverCartModel = result.data!["getCart"];

      if (serverCartModel != null) {
        cart = cartListFromJson(serverCartModel);
        return cart;
      }
    }
    return cart;
  }

  Future<bool> removeCart(String userId, String cartId) async {
    String cartGql = """mutation removeCart(\$id: String, \$userId: String) {
          removeCart(id: \$id, userId: \$userId)
        }""";
    GraphQLConfiguration graphQLConfiguration = GraphQLConfiguration();
    GraphQLClient _client = graphQLConfiguration.clientToQuery();
    final vble = {"userId": userId, "id": cartId};
    QueryResult result = await _client.mutate(
      MutationOptions(
        document: gql(cartGql),
        variables: vble,
      ),
    );
    if (!result.hasException) {
      var removeCart = result.data!['removeCart'];
      if (removeCart != null) {
        removeCartDetail = removeCartFromJson(removeCart);
      }
    }
    return removeCartDetail;
  }

  Future<bool> updateWishlist(String userId, String packId) async {
    String wishlistGql =
        """mutation changeWishlist(\$userId: String, \$packId: String) {
              changeWishlist(userId: \$userId, packId: \$packId) {
                _id
                __typename
              }
            }""";
    GraphQLConfiguration graphQLConfiguration = GraphQLConfiguration();
    GraphQLClient _client = graphQLConfiguration.clientToQuery();
    final vble = {"packId": packId, "userId": userId};
    QueryResult result = await _client.mutate(
      MutationOptions(
        document: gql(wishlistGql),
        variables: vble,
      ),
    );
    if (!result.hasException) {
      var wishlist = result.data!['changeWishlist'];
      if (wishlist != null && wishlist["_id"] != null) {
        return true;
      } else {
        return true;
      }
    }
    return false;
  }

  Future updateCart(UpdateCartRequest updateCartRequest) async {
    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var updateCartGql = """ 
            mutation updateCart(\$cart: CartInput, \$id: String) {
              updateCart(cart: \$cart, id: \$id) {
                _id
                packName
                packId
                packImage
                packSku
                setId
                quantity
                piece
                setPrice
                price
                variant
                igst
                cgst
                sgst
                variantValue
                isOutofstock
                maximumQuantity
                __typename
              }
            }

            """;

    final vble = {"cart": updateCartRequest.cart, "id": updateCartRequest.id};
    QueryResult result = await _client.query(QueryOptions(
      document: gql(updateCartGql),
      variables: vble,
      fetchPolicy: FetchPolicy.networkOnly,
    ));

    if (!result.hasException) {
      var cartUpdate = result.data!['updateCart'];

      if (cartUpdate != null && cartUpdate.length > 0) {
        updatedCart = cartFromJson(cartUpdate);
        return updatedCart;
      }
    }
    return updatedCart;
  }

  Future addCart(AddCartRequest addCartRequest) async {
    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var addCartGql = """ 
            mutation addCart(\$cart: CartInput) {
                addCart(cart: \$cart)
              }
            """;

    final vble = {"cart": addCartRequest};
    QueryResult result = await _client.query(QueryOptions(
      document: gql(addCartGql),
      variables: vble,
      fetchPolicy: FetchPolicy.networkOnly,
    ));

    if (!result.hasException) {
      var cartAdd = result.data!['addCart'];

      if (cartAdd != null && cartAdd.length > 0) {
        addedCart = addCartFromJson(cartAdd);
        return addedCart;
      }
    }
    return addedCart;
  }
}

==> 1.0.50.tar.gz: lib/modules/cart/cart_repo.dart <==
import 'package:graphql_flutter/graphql_flutter.dart';

import '../../GraphQLConfiguration.dart';
import 'cart_model.dart';

class CartRepo {
  var graphQLConfiguration;

  var serverCartCount;
  var cart = [];
  var removeCartDetail;
  var updatedCart, addedCart;
  CartRepo() {
    graphQLConfiguration = GraphQLConfiguration();
  }

  Future getServerCartCount(String userId) async {
    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var cartCountGql = """ 
              query serverCartCount(\$userId: String) {
              serverCartCount(userId: \$userId)
            }
            """;

    final vble = {
      "userId": userId,
    };
    QueryResult result = await _client.query(QueryOptions(
      document: gql(cartCountGql),
      variables: vble,
      fetchPolicy: FetchPolicy.networkOnly,
    ));

    if (!result.hasException) {
      var serverCartCountModel = result.data!["serverCartCount"];

      if (serverCartCountModel != null) {
        serverCartCount = cartCountFromJson(serverCartCountModel);
        return serverCartCount;
      }
    }
    return serverCartCount;
  }

  Future getCart(String userId) async {
    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var cartGql = """ 
             query getCart(\$userId: String) {
                  getCart(userId: \$userId) {
                    _id
                    packName
                    packId
                    packImage
                    packSku
                    setId
                    quantity
                    piece
                    setPrice
                    price
                    variant
                    igst
                    cgst
                    sgst
                    variantValue
                    isOutofstock
                    maximumQuantity
                    __typename
                  }
                }
            """;

    final vble = {
      "userId": userId,
    };
    QueryResult result = await _client.query(QueryOptions(
      document: gql(cartGql),
      variables: vble,
      fetchPolicy: FetchPolicy.networkOnly,
    ));

    if (!result.hasException) {
      var serverCartModel = result.data!["getCart"];

      if (serverCartModel != null) {
        cart = cartListFromJson(serverCartModel);
        return cart;
      }
    }
    return cart;
  }

  Future<bool> removeCart(String userId, String cartId) async {
    String cartGql = """mutation removeCart(\$id: String, \$userId: String) {
          removeCart(id: \$id, userId: \$userId)
        }""";
    GraphQLConfiguration graphQLConfiguration = GraphQLConfiguration();
    GraphQLClient _client = graphQLConfiguration.clientToQuery();
    final vble = {"userId": userId, "id": cartId};
    QueryResult result = await _client.mutate(
      MutationOptions(
        document: gql(cartGql),
        variables: vble,
      ),
    );
    if (!result.hasException) {
      var removeCart = result.data!['removeCart'];
      if (removeCart != null) {
        removeCartDetail = removeCartFromJson(removeCart);
      }
    }
    return removeCartDetail;
  }

  Future<bool> updateWishlist(String userId, String packId) async {
    String wishlistGql =
        """mutation changeWishlist(\$userId: String, \$packId: String) {
              changeWishlist(userId: \$userId, packId: \$packId) {
                _id
                __typename
              }
            }""";
    GraphQLConfiguration graphQLConfiguration = GraphQLConfiguration();
    GraphQLClient _client = graphQLConfiguration.clientToQuery();
    final vble = {"packId": packId, "userId": userId};
    QueryResult result = await _client.mutate(
      MutationOptions(
        document: gql(wishlistGql),
        variables: vble,
      ),
    );
    if (!result.hasException) {
      var wishlist = result.data!['changeWishlist'];
      if (wishlist != null && wishlist["_id"] != null) {
        return true;
      } else {
        return true;
      }
    }
    return false;
  }

  Future updateCart(UpdateCartRequest updateCartRequest) async {
    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var updateCartGql = """ 
            mutation updateCart(\$cart: CartInput, \$id: String) {
              updateCart(cart: \$cart, id: \$id) {
                _id
                packName
                packId
                packImage
                packSku
                setId
                quantity
                piece
                setPrice
                price
                variant
                igst
                cgst
                sgst
                variantValue
                isOutofstock
                maximumQuantity
                __typename
              }
            }

            """;

    final vble = {"cart": updateCartRequest.cart, "id": updateCartRequest.id};
    QueryResult result = await _client.query(QueryOptions(
      document: gql(updateCartGql),
      variables: vble,
      fetchPolicy: FetchPolicy.networkOnly,
    ));

    if (!result.hasException) {
      var cartUpdate = result.data!['updateCart'];

      if (cartUpdate != null && cartUpdate.length > 0) {
        updatedCart = cartFromJson(cartUpdate);
        return updatedCart;
      }
    }
    return updatedCart;
  }

  Future addCart(AddCartRequest addCartRequest) async {
    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var addCartGql = """ 
            mutation addCart(\$cart: CartInput) {
                addCart(cart: \$cart)
              }
            """;

    final vble = {"cart": addCartRequest};
    QueryResult result = await _client.query(QueryOptions(
      document: gql(addCartGql),
      variables: vble,
      fetchPolicy: FetchPolicy.networkOnly,
    ));

    if (!result.hasException) {
      var cartAdd = result.data!['addCart'];

      if (cartAdd != null) {
        addedCart = addCartFromJson(cartAdd);
        return addedCart;
      }
    }
    return addedCart;
  }
}
